@@ -3,7 +3,7 @@ use v5.24;
 use Carp;
 use English      qw< -no_match_vars >;
 use experimental qw< signatures >;
-{ our $VERSION = '0.001' }
+{ our $VERSION = '0.001002' }
 
 use JSON::PP qw< decode_json >;
 
@@ -184,7 +184,8 @@ sub data_to_file {
    require File::Temp;
    my ($fh, $filename) = File::Temp::tempfile(UNLINK => (!$keep));
    binmode $fh, ':raw';
-   print {$fh} ref($_[0]) ? ${$_[0]} : $_[0];
+   (print {$fh} ref($_[0]) ? ${$_[0]} : $_[0]) or croak "print: $OS_ERROR";
+   close $fh or croak "close: $OS_ERROR";
    return $filename;
 } ## end sub data_to_file
 
